@@ -81,23 +81,18 @@ class TrinoHook(DbApiHook):
                 delegate=_boolify(extra.get('kerberos__delegate', False)),
                 ca_bundle=extra.get('kerberos__ca_bundle'),
             )
-
         trino_conn = trino.dbapi.connect(
             host=db.host,
             port=db.port,
             user=db.login,
-            source=db.extra_dejson.get('source', 'airflow'),
-            http_scheme=db.extra_dejson.get('protocol', 'http'),
-            catalog=db.extra_dejson.get('catalog', 'hive'),
+            source=extra.get('source', 'airflow'),
+            http_scheme=extra.get('protocol', 'http'),
+            catalog=extra.get('catalog', 'hive'),
             schema=db.schema,
             auth=auth,
             isolation_level=self.get_isolation_level(),  # type: ignore[func-returns-value]
+            verify=_boolify(extra.get('verify', True)),
         )
-        if extra.get('verify') is not None:
-            # Unfortunately verify parameter is available via public API.
-            # The PR is merged in the trino library, but has not been released.
-            # See: https://github.com/trinodb/trino-python-client/pull/31
-            trino_conn._http_session.verify = _boolify(extra['verify'])
 
         return trino_conn
 
